 
function m = getModel()
m = pwGetEmptyModel;

%% meta information
m.ID          = 'Reference';
m.name        = 'Reference model';
m.description = 'Model M_Ref from Witt et al. (2012), PLoS ONE';
m.authors     = {'Johannes Witt'};
m.dates       = {'2012-02-15'};
m.type        = 'PW-2-0';

%relaxation time in h
m.tStart=-120;

%state variables
m = pwAddX(m,'ILR',  1,'fix');%IL-1 receptor
m = pwAddX(m,'ILRc', 0,'fix');%IL-1 receptor complex
m = pwAddX(m,'IKKp', 0,'fix');%phosphorylated IKK
                              %unphosphorylated IKK can be calculated as (1-IKKp)
m = pwAddX(m,'PP2A', 1,'fix');%PP2A
m = pwAddX(m,'IkBa', 0,'fix');%cytosolic free IkBa
m = pwAddX(m,'IkBat',0,'fix');%IkBa mRNA
m = pwAddX(m,'NFkBn',0,'fix');%nuclear NFkB
                              %cytosolic IkBa-NFkB complex can be
                              %calculated as (nfkbtot-NFkBn/kv)
m = pwAddX(m,'IkBan',0,'fix');%nuclear, free IkBa

%ODEs
m = pwAddODE(m,'d(ILR)/dt   = -ka*il1*ILR + (1-uv*uvinh)*(1-chx)*kilr - ILR*kilr');
m = pwAddODE(m,'d(ILRc)/dt  = ka*il1*ILR - ki*ILRc');
m = pwAddODE(m,'d(IKKp)/dt  = kp*ILRc*(1-IKKp) + kpconst*(1-IKKp) - kdp*PP2A*IKKp/(Km+IKKp)');
m = pwAddODE(m,'d(PP2A)/dt  = -kuv*uv*PP2A');
m = pwAddODE(m,'d(IkBa)/dt  = -a2*(1-mg)*IKKp*IkBa + (1-chx)*(1-uv*uvinh)*c4a*IkBat - c5a*(1-mg)*IkBa - i1a*IkBa + e1a*IkBan');
m = pwAddODE(m,'d(IkBat)/dt = c1a*NFkBn  - c3a*IkBat');
m = pwAddODE(m,'d(NFkBn)/dt = kv*a3*(1-mg)*IKKp*(nfkbtot-NFkBn/kv) - a1*IkBan*NFkBn + (1-mg)*c6a*kv*(nfkbtot-NFkBn/kv)');
m = pwAddODE(m,'d(IkBan)/dt = -a1*IkBan*NFkBn + i1a*kv*IkBa - e1a*kv*IkBan');

%Parameter values of M_Ref fitted to all data. 
%parameters    name    initial value type   lower bound    upper bound
m = pwAddK(m, 'kilr',    0.0677174, 'global',9.2e-6*3600,  2.78e-5*3600);
m = pwAddK(m, 'ka',      23547.1,   'global',1e-4*3600,    1000*3600);
m = pwAddK(m, 'ki',      11.6981,   'global',1e-7*3600,    1*3600);
m = pwAddK(m, 'kp',      342,       'global',1e-7*3600,    0.095*3600);
m = pwAddK(m, 'kdp',     2.56572,   'global',1e-7*3600,    0.05*3600);
m = pwAddK(m, 'Km',      0.0137149, 'global',0.0001,       10);
m = pwAddK(m, 'kuv',     1.28624,   'global',1e-7*3600,    1*3600);
m = pwAddK(m, 'i1a',     2.412,     'global',0.00019*3600, 0.00067*3600);
m = pwAddK(m, 'a1',      3600,      'global',0.3*3600,     1*3600);
m = pwAddK(m, 'a2',      55.523,    'global',1e-7*3600,    0.8*3600);
m = pwAddK(m, 'a3',      51.7329,   'global',1e-7*3600,    0.8*3600);
m = pwAddK(m, 'c5a',     2.68463,   'global',0.000578*3600,2e-3*3600);
m = pwAddK(m, 'c3a',     2.14408,   'global',0.00026*3600, 0.00077*3600);
m = pwAddK(m, 'c1a',     0.003312,  'global',1e-10*3600,   9.2e-7*3600);
m = pwAddK(m, 'c4a',     1800,      'global',1e-7*3600,    0.5*3600);
m = pwAddK(m, 'uvinh',   0.924394,  'global',1e-8,         1);
m = pwAddK(m, 'kpconst', 0.00763511,'global',1e-10*3600,   9.3e-3*3600);
m = pwAddK(m, 'c6a',     0.0792,    'fix');
m = pwAddK(m, 'kv',      2.9,       'fix');
m = pwAddK(m, 'ie',      2,         'fix');
m = pwAddK(m, 'volume',  2,         'fix');
m = pwAddK(m, 'numNFkB', 60000,     'fix'); 

%default stimulations 
m = pwAddU(m,'il1','steps',[-6],[0]); 
m = pwAddU(m,'uv', 'steps',[-6],[0]);
m = pwAddU(m,'mg', 'steps',[-6],[0]);
m = pwAddU(m,'chx','steps',[-6],[0]);

%observables
m = pwAddY(m, 'IkBa+(nfkbtot-NFkBn/kv)+IkBan/kv','IkBaobs', 'scale_IkBaobs');%total cellular IkBa
m = pwAddY(m, 'IKKp',                   'IKKobs',  'scale_IKK');
m = pwAddY(m, 'NFkBn',                  'NFkBnobs','scale_NFkB');

%scaling parameter
m = pwAddS(m, 'scale_IKK',     0.975328, 'global',0.1, 100);
m = pwAddS(m, 'scale_IkBaobs', 14.629,  'global',0.1, 100);
m = pwAddS(m, 'scale_NFkB',    8.5082,  'local' ,0.1, 100);

%derived parameters
m = pwAddRule(m,'nfkbtot', {},{'numNFkB','kv','volume'},'k1*(1+1/k2)/(6e5*k3)');
m = pwAddRule(m,'e1a',     {},{'i1a','ie'},             'k1/k2');



